colour.colorimetry.blackbody Module — Colour 0.3.0 documentation

# colour.colorimetry.blackbody Module

## Blackbody - Planckian Radiator

Defines objects to compute the spectral radiance of a planckian radiator and its spectral power distribution.

See also

Blackbody IPython Notebook colour.colorimetry.spectrum.SpectralPowerDistribution

`colour.colorimetry.blackbody.` `planck_law`(*args, **kwds)

  Returns the spectral radiance of a blackbody at thermodynamic temperature \(T[K]\) in a medium having index of refraction \(n\).

  Notes

  The following form implementation is expressed in term of wavelength. The SI unit of radiance is watts per steradian per square metre.

  References

  [1] | CIE 015:2004 Colorimetry, 3rd edition: Appendix E. Information on the Use of Planck”s Equation for Standard Air.

  Parameters: | wavelength (numeric) – Wavelength in meters. temperature (numeric) – Temperature \(T[K]\) in kelvin degrees. c1 (numeric, optional) – The official value of \(c1\) is provided by the Committee on Data for Science and Technology (CODATA), and is \(c1=3,741771x10.16\ W/m_2\) (Mohr and Taylor, 2000). c2 (numeric, optional) – Since \(T\) is measured on the International Temperature Scale, the value of \(c2\) used in colorimetry should follow that adopted in the current International Temperature Scale (ITS-90) (Preston-Thomas, 1990; Mielenz et aI., 1991), namely \(c2=1,4388x10.2\ m/K\). n (numeric, optional) – Medium index of refraction. For dry air at 15°C and 101 325 Pa, containing 0,03 percent by volume of carbon dioxide, it is approximately 1,00028 throughout the visible region although CIE 15:2004 recommends using \(n=1\).
  Returns: | Radiance in watts per steradian per square metre.
  Return type: | numeric

  Examples

      >>> # Doctests ellipsis for Python 2.x compatibility.
      >>> planck_law(500 * 1e-9, 5500)
      20472701909806.5...

`colour.colorimetry.blackbody.` `blackbody_spectral_radiance`(*args, **kwds)

  Returns the spectral radiance of a blackbody at thermodynamic temperature \(T[K]\) in a medium having index of refraction \(n\).

  Notes

  The following form implementation is expressed in term of wavelength. The SI unit of radiance is watts per steradian per square metre.

  References

  [1] | CIE 015:2004 Colorimetry, 3rd edition: Appendix E. Information on the Use of Planck”s Equation for Standard Air.

  Parameters: | wavelength (numeric) – Wavelength in meters. temperature (numeric) – Temperature \(T[K]\) in kelvin degrees. c1 (numeric, optional) – The official value of \(c1\) is provided by the Committee on Data for Science and Technology (CODATA), and is \(c1=3,741771x10.16\ W/m_2\) (Mohr and Taylor, 2000). c2 (numeric, optional) – Since \(T\) is measured on the International Temperature Scale, the value of \(c2\) used in colorimetry should follow that adopted in the current International Temperature Scale (ITS-90) (Preston-Thomas, 1990; Mielenz et aI., 1991), namely \(c2=1,4388x10.2\ m/K\). n (numeric, optional) – Medium index of refraction. For dry air at 15°C and 101 325 Pa, containing 0,03 percent by volume of carbon dioxide, it is approximately 1,00028 throughout the visible region although CIE 15:2004 recommends using \(n=1\).
  Returns: | Radiance in watts per steradian per square metre.
  Return type: | numeric

  Examples

      >>> # Doctests ellipsis for Python 2.x compatibility.
      >>> planck_law(500 * 1e-9, 5500)
      20472701909806.5...

`colour.colorimetry.blackbody.` `blackbody_spd`(temperature, shape=SpectralShape(360, 830, 1), c1=3.741771e-16, c2=0.014388, n=1)

  Returns the spectral power distribution of the planckian radiator for given temperature \(T[K]\).

  Parameters: | temperature (numeric) – Temperature \(T[K]\) in kelvin degrees. shape (SpectralShape, optional) – Spectral shape used to create the spectral power distribution of the planckian radiator. c1 (numeric, optional) – The official value of \(c1\) is provided by the Committee on Data for Science and Technology (CODATA), and is \(c1=3,741771x10.16\ W/m_2\) (Mohr and Taylor, 2000). c2 (numeric, optional) – Since \(T\) is measured on the International Temperature Scale, the value of \(c2\) used in colorimetry should follow that adopted in the current International Temperature Scale (ITS-90) (Preston-Thomas, 1990; Mielenz et aI., 1991), namely \(c2=1,4388x10.2\ m/K\). n (numeric, optional) – Medium index of refraction. For dry air at 15°C and 101 325 Pa, containing 0,03 percent by volume of carbon dioxide, it is approximately 1,00028 throughout the visible region although CIE 15:2004 recommends using \(n=1\).
  Returns: | Blackbody spectral power distribution.
  Return type: | SpectralPowerDistribution

  Examples

      >>> from colour import STANDARD_OBSERVERS_CMFS
      >>> cmfs = STANDARD_OBSERVERS_CMFS.get('CIE 1931 2 Degree Standard Observer')
      >>> blackbody_spd(5000, cmfs.shape)
      <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x...>